pub enum CommitError {
MissingEntry(EntryRef),
MissingParent(EntryRef),
MissingDoc(Hash),
MissingDocRef {
doc: Hash,
target: Hash,
},
MissingSchema {
doc: Hash,
schema: Hash,
},
}Variants
MissingEntry(EntryRef)
Tried to change or delete an entry but it wasn’t in the DB
MissingParent(EntryRef)
Tried to add an entry but its parent document wasn’t in the DB
MissingDoc(Hash)
Tried to change a document’s references but it wasn’t in the DB
MissingDocRef
Tried to change a document’s references but the ref wasn’t in the document
MissingSchema
Tried to add a document but the schema was missing